@@ -42,10 +42,6 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
-pub mod event;
-pub use self::event::Event;
-pub mod event_request;
-pub use self::event_request::EventRequest;
 pub mod event_source;
 pub use self::event_source::EventSource;
 pub mod event_status;
@@ -188,8 +184,6 @@ pub mod paginated_task_status_list;
 pub use self::paginated_task_status_list::PaginatedTaskStatusList;
 pub mod paginated_telemetry_event_polymorphic_list;
 pub use self::paginated_telemetry_event_polymorphic_list::PaginatedTelemetryEventPolymorphicList;
-pub mod paginated_test_event_list;
-pub use self::paginated_test_event_list::PaginatedTestEventList;
 pub mod partner3_d_geeks_alert;
 pub use self::partner3_d_geeks_alert::Partner3DGeeksAlert;
 pub mod partner3_d_geeks_metadata;
